<?php

/**
 * Copyright © 2016 Magento. All rights reserved.
 * See COPYING.txt for license details.
 */

namespace FiloBlu\ExtAmastyGeoipRedirect\Controller\Change;

/**
 * Responsible for loading page content.
 *
 * This is a basic controller that only loads the corresponding layout file. It may duplicate other such
 * controllers, and thus it is considered tech debt. This code duplication will be resolved in future releases.
 */
class Country extends \Magento\Framework\App\Action\Action {

    /** @var \Magento\Framework\View\Result\PageFactory */
    protected $resultJsonFactory;
    protected $_helper;
    protected $_storeManager;

    /**
     * @var \Magento\Customer\Model\Session
     */
    protected $customerSession;

    /**
     * @var \Magento\Store\Api\StoreCookieManagerInterface
     */
    protected $storeCookieManager;

    public function __construct(
    \Magento\Framework\App\Action\Context $context, \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory, \FiloBlu\ExtAmastyGeoipRedirect\Helper\Data $helper, \Magento\Store\Model\StoreManagerInterface $storeManager, \Magento\Customer\Model\Session $customerSession, \Magento\Store\Api\StoreCookieManagerInterface $storeCookieManager
    ) {
        $this->resultJsonFactory = $resultJsonFactory;
        $this->_helper = $helper;
        $this->_storeManager = $storeManager;
        $this->customerSession = $customerSession;
        $this->storeCookieManager = $storeCookieManager;

        parent::__construct($context);
    }

    public function execute() {

        if ($this->getRequest()->isPost() && $this->getRequest()->getPost('store_id') && $this->getRequest()->getPost('country_id')) {

            $storeId = $this->getRequest()->getPost('store_id');
            $countryId = $this->getRequest()->getPost('country_id');


            $store = $this->_storeManager->getStore($storeId);
            $websiteId = $store->getWebsiteId();
            $stores = $this->_storeManager->getWebsite($websiteId)->getStores();

            $languages = array();

            foreach ($stores as $language) {
                if ($language->isActive()) {
                    array_push($languages, [
                        "name" => $language->getName(),
                        "store_id" => $language->getId(),
                        "url" => $language->getBaseUrl(),
                        "country_id" => $countryId
                    ]);
                }
            }

            if (count($languages) == 1) {

                $this->_helper->setCountryCookie($countryId);
                $this->_helper->setStoreCookie($storeId);
                $this->storeCookieManager->setStoreCookie($store);
            }

            $resultJson = $this->resultJsonFactory->create();

            $resultJson->setData($languages);

            return $resultJson;
        } else {
            return null;
        }
    }

}
